@@ -29,14 +29,14 @@
 #include <AkonadiCore/Collection>
 
 #include <QDateTime>
-#include <QObject>
-#include <QEventLoop>
 #include <QElapsedTimer>
+#include <QEventLoop>
+#include <QObject>
 #include <QTimeZone>
 
-#include <stdlib.h>
-#include <iostream>
 #include <QStandardPaths>
+#include <iostream>
+#include <stdlib.h>
 
 using namespace KCalendarCore;
 using namespace std;
@@ -61,13 +61,11 @@ bool KonsoleKalendarAdd::addEvent()
     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendaradd.cpp::addEvent()";
 
     if (m_variables->isDryRun()) {
-        cout << i18n("Insert Event <Dry Run>:").toLocal8Bit().data()
-             << endl;
+        cout << i18n("Insert Event <Dry Run>:").toLocal8Bit().data() << endl;
         printSpecs();
     } else {
         if (m_variables->isVerbose()) {
-            cout << i18n("Insert Event <Verbose>:").toLocal8Bit().data()
-                 << endl;
+            cout << i18n("Insert Event <Verbose>:").toLocal8Bit().data() << endl;
             printSpecs();
         }
 
@@ -83,16 +81,16 @@ bool KonsoleKalendarAdd::addEvent()
 
         Akonadi::CalendarBase::Ptr calendar = m_variables->getCalendar();
         QEventLoop loop;
-        QObject::connect(calendar.data(), &Akonadi::CalendarBase::createFinished,
-                         &loop, &QEventLoop::quit);
+        QObject::connect(calendar.data(), &Akonadi::CalendarBase::createFinished, &loop, &QEventLoop::quit);
         QElapsedTimer t;
         t.start();
-        Q_ASSERT(calendar->incidence(event->uid()) == nullptr);  // can't exist yet
+        Q_ASSERT(calendar->incidence(event->uid()) == nullptr); // can't exist yet
         if (!m_variables->allowGui()) {
             Akonadi::IncidenceChanger *changer = calendar->incidenceChanger();
             changer->setShowDialogsOnError(false);
-            Akonadi::Collection collection = m_variables->collectionId() != -1 ? Akonadi::Collection(m_variables->collectionId())
-                                             : Akonadi::Collection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+            Akonadi::Collection collection = m_variables->collectionId() != -1
+                ? Akonadi::Collection(m_variables->collectionId())
+                : Akonadi::Collection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
 
             if (!collection.isValid()) {
                 cout << i18n("Calendar is invalid. Please specify one with --calendar").toLocal8Bit().data() << "\n";
@@ -106,13 +104,9 @@ bool KonsoleKalendarAdd::addEvent()
         qCDebug(KONSOLEKALENDAR_LOG) << "Creation took " << t.elapsed() << "ms.";
         status = calendar->incidence(event->uid()) != nullptr;
         if (status) {
-            cout << i18n("Success: \"%1\" inserted",
-                         m_variables->getSummary()).toLocal8Bit().data()
-                 << endl;
+            cout << i18n("Success: \"%1\" inserted", m_variables->getSummary()).toLocal8Bit().data() << endl;
         } else {
-            cout << i18n("Failure: \"%1\" not inserted",
-                         m_variables->getSummary()).toLocal8Bit().data()
-                 << endl;
+            cout << i18n("Failure: \"%1\" not inserted", m_variables->getSummary()).toLocal8Bit().data() << endl;
             status = false;
         }
     }
@@ -127,8 +121,7 @@ bool KonsoleKalendarAdd::addImportedCalendar()
     FileStorage instore(cal, m_variables->getImportFile());
     if (!instore.load()) {
         qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendaradd.cpp::importCalendar() |"
-                                     << "Can't import file:"
-                                     << m_variables->getImportFile();
+                                     << "Can't import file:" << m_variables->getImportFile();
         return false;
     }
     Akonadi::CalendarBase::Ptr calendar = m_variables->getCalendar();
@@ -137,7 +130,7 @@ bool KonsoleKalendarAdd::addImportedCalendar()
         Akonadi::IncidenceChanger *changer = calendar->incidenceChanger();
         changer->setShowDialogsOnError(false);
         Akonadi::Collection collection = m_variables->collectionId() != -1 ? Akonadi::Collection(m_variables->collectionId())
-                                         : Akonadi::Collection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+                                                                           : Akonadi::Collection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
 
         if (!collection.isValid()) {
             cout << i18n("Calendar is invalid. Please specify one with --calendar").toLocal8Bit().data() << "\n";
@@ -148,22 +141,20 @@ bool KonsoleKalendarAdd::addImportedCalendar()
     }
 
     QEventLoop loop;
-    QObject::connect(calendar.data(), &Akonadi::CalendarBase::createFinished,
-                     &loop, &QEventLoop::quit);
+    QObject::connect(calendar.data(), &Akonadi::CalendarBase::createFinished, &loop, &QEventLoop::quit);
     QElapsedTimer t;
-    foreach (const auto &event, cal->rawEvents()) {
+    const auto rawEvents = cal->rawEvents();
+    for (const auto &event : rawEvents) {
         if (calendar->incidence(event->uid()) != nullptr) {
             if (m_variables->isVerbose()) {
-                cout << i18n("Insert Event skipped, because UID \"%1\" is already known. <Verbose>", event->uid()).toLocal8Bit().data()
-                     << endl;
+                cout << i18n("Insert Event skipped, because UID \"%1\" is already known. <Verbose>", event->uid()).toLocal8Bit().data() << endl;
             } else {
                 qCInfo(KONSOLEKALENDAR_LOG) << "Event with UID " << event->uid() << "is already in calendar, skipping import of this Event.";
             }
             continue;
         }
         if (m_variables->isVerbose()) {
-            cout << i18n("Add Event with UID \"%1\". <Verbose>", event->uid()).toLocal8Bit().data()
-                 << endl;
+            cout << i18n("Add Event with UID \"%1\". <Verbose>", event->uid()).toLocal8Bit().data() << endl;
         }
         if (m_variables->isDryRun()) {
             continue;
@@ -171,41 +162,30 @@ bool KonsoleKalendarAdd::addImportedCalendar()
         t.start();
         calendar->addEvent(event);
         loop.exec();
-        qCDebug(KONSOLEKALENDAR_LOG) << "Creation of event took " << t.elapsed() << "ms." << "status: "<< (calendar->incidence(event->uid()) != nullptr);
+        qCDebug(KONSOLEKALENDAR_LOG) << "Creation of event took " << t.elapsed() << "ms."
+                                     << "status: " << (calendar->incidence(event->uid()) != nullptr);
         if (calendar->incidence(event->uid()) == nullptr) {
             return false;
         }
     }
     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendaradd.cpp::importCalendar() |"
-                                 << "Successfully imported file:"
-                                 << m_variables->getImportFile();
+                                 << "Successfully imported file:" << m_variables->getImportFile();
     return true;
 }
 
 void KonsoleKalendarAdd::printSpecs()
 {
-    cout << i18n("  What:  %1",
-                 m_variables->getSummary()).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  What:  %1", m_variables->getSummary()).toLocal8Bit().data() << endl;
 
-    cout << i18n("  Begin: %1",
-                 m_variables->getStartDateTime().toString(Qt::TextDate)).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  Begin: %1", m_variables->getStartDateTime().toString(Qt::TextDate)).toLocal8Bit().data() << endl;
 
-    cout << i18n("  End:   %1",
-                 m_variables->getEndDateTime().toString(Qt::TextDate)).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  End:   %1", m_variables->getEndDateTime().toString(Qt::TextDate)).toLocal8Bit().data() << endl;
 
     if (m_variables->getFloating() == true) {
-        cout << i18n("  No Time Associated with Event").toLocal8Bit().data()
-             << endl;
+        cout << i18n("  No Time Associated with Event").toLocal8Bit().data() << endl;
     }
 
-    cout << i18n("  Desc:  %1",
-                 m_variables->getDescription()).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  Desc:  %1", m_variables->getDescription()).toLocal8Bit().data() << endl;
 
-    cout << i18n("  Location:  %1",
-                 m_variables->getLocation()).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  Location:  %1", m_variables->getLocation()).toLocal8Bit().data() << endl;
 }
